@@ -19,17 +19,19 @@ __all__ = ['main', 'minify', 'minify_stream']
 def dirwalk(dir):
     """Walk a directory tree, using a generator of files"""
     for f in os.listdir(dir):
-        fullpath = os.path.join(dir,f)
+        fullpath = os.path.join(dir, f)
         if os.path.isdir(fullpath) and not os.path.islink(fullpath):
             for x in dirwalk(fullpath):  # recurse into subdir
-                yield x
+                if x.endswith('.js'):
+                    yield x
         else:
-            yield fullpath
+            if fullpath.endswith('.js'):
+                yield fullpath
 
 
 def is_min(filename):
     """Check if this file is alrady a minified file"""
-    return re.search("^(min).js$", filename)
+    return filename.endswith('min.js')
 
 
 def minify(filename):
@@ -42,6 +44,7 @@ def minify(filename):
                 jsm = JavascriptMinify()
                 jsm.minify(shrink_me, tobemin)
 
+
 def minify_stream(instream, outstream):
     """Given an input/output stream, minify the JS"""
     jsm = JavascriptMinify()
@@ -56,14 +59,16 @@ def _parse_args():
     """
 
     parser = argparse.ArgumentParser(description=desc)
-    parser.add_argument('--path', '-p', dest='path',
-                            action='store',
-                            default=None,
-                            required=False,
-                            help='Specify the path to minimize (directory or file)')
+    parser.add_argument('--path', '-p',
+        dest='path',
+        action='store',
+        default=None,
+        required=False,
+        help='Specify the path to minimize (directory or file)')
     args = parser.parse_args()
     return args
 
+
 def main():
     args = _parse_args()
 
